/*
 * Copyright (C) 2021 Alistair Leslie-Hughes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#if 0
#pragma makedep install
#endif

[
    object,
    uuid(0c733a10-2a1c-11ce-ade5-00aa0044773d),
    pointer_default(unique)
]

interface IColumnsRowset : IUnknown
{
    [local]
    HRESULT GetAvailableColumns( [in, out] DBORDINAL *count, [out, size_is(,(ULONG)*count)] DBID **columns);

    [call_as(GetAvailableColumns)]
    HRESULT RemoteGetAvailableColumns([in, out] DBORDINAL *count, [out, size_is(,(ULONG)*count)] DBID **columns,
        [out] IErrorInfo **error);

    [local]
    HRESULT GetColumnsRowset([in] IUnknown *outer, [in] DBORDINAL count, [in, size_is((ULONG)count)] const DBID columns[],
        [in] REFIID riid, [in] ULONG property_cnt, [in, out, size_is((ULONG)property_cnt)] DBPROPSET property_sets[],
        [out, iid_is(riid)] IUnknown **rowset);

    [call_as(GetColumnsRowset)]
    HRESULT RemoteGetColumnsRowset([in] IUnknown *outer, [in] DBORDINAL count, [in, unique, size_is((ULONG)count)] const DBID *columns,
        [in] REFIID riid, [in] ULONG property_cnt, [in, unique, size_is((ULONG)property_cnt)] DBPROPSET * roperty_sets,
        [out, iid_is(riid)] IUnknown **rowset, [in] ULONG props_cnt, [out, size_is((ULONG)props_cnt)] DBPROPSTATUS *prop_status,
        [out] IErrorInfo **error);
}
