/*
 * Copyright (C) 2014 Martin Storsjo
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

import "wtypes.idl";

typedef struct HSTRING__
{
    int unused;
} HSTRING__;

typedef [wire_marshal(wireBSTR), unique] HSTRING__* HSTRING;

cpp_quote("DECLARE_HANDLE(HSTRING_BUFFER);")

cpp_quote("typedef struct HSTRING_HEADER")
cpp_quote("{")
cpp_quote("    union")
cpp_quote("    {")
cpp_quote("        PVOID Reserved1;")
cpp_quote("#ifdef _WIN64")
cpp_quote("        char Reserved2[24];")
cpp_quote("#else")
cpp_quote("        char Reserved2[20];")
cpp_quote("#endif")
cpp_quote("    } Reserved;")
cpp_quote("} HSTRING_HEADER;")
