/*
 * Copyright (C) 2006 Mike McCormack
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
cpp_quote("#ifdef _WIN64")
cpp_quote("#pragma pack(push,8)")
cpp_quote("#else")
cpp_quote("#pragma pack(push,2)")
cpp_quote("#endif")
cpp_quote("")

import "wtypes.idl";
import "oaidl.idl";
import "ocidl.idl";
import "propidl.idl";
import "urlmon.idl";

typedef ULONG_PTR DBBYTEOFFSET;
typedef LONG_PTR  DBROWOFFSET;
typedef LONG_PTR  DBROWCOUNT;
typedef ULONG_PTR DBCOUNTITEM;
typedef ULONG_PTR DBLENGTH;
typedef ULONG_PTR DBORDINAL;
typedef ULONG_PTR DBBKMARK;
typedef DWORD_PTR DB_DWRESERVE;
typedef ULONG_PTR DBREFCOUNT;
typedef ULONG_PTR DB_UPARAMS;
typedef LONG_PTR  DB_LPARAMS;
typedef DWORD_PTR DBHASHVALUE;
typedef LONG_PTR DB_LRESERVE;

#include "dbs.idl"

#include "access.idl"
#include "rstbas.idl"
#include "rstinf.idl"
#include "rstloc.idl"
#include "rstscr.idl"
#include "rstxsc.idl"
#include "chprst.idl"
#include "rstfnd.idl"
#include "rstvw.idl"
#include "vwchp.idl"
#include "vwflt.idl"
#include "cmdbas.idl"
#include "cmdtxt.idl"
#include "colinf.idl"
#include "colrst.idl"
#include "dbccmd.idl"
#include "dbcses.idl"
#include "srcrst.idl"
#include "dbprop.idl"
#include "dbinit.idl"
#include "dbdsad.idl"
#include "asynot.idl"
#include "asysta.idl"
#include "sesprp.idl"
#include "rstnot.idl"
#include "opnrst.idl"
#include "dbsrst.idl"
#include "row.idl"
#include "rowchg.idl"
#include "rowpos.idl"
#include "rowpsc.idl"
#include "binres.idl"
#include "crtrow.idl"
#include "errrec.idl"
#include "errlup.idl"
#include "getdts.idl"
#include "cmdstrm.idl"
#include "cmdprp.idl"
#include "cvttyp.idl"
#include "cmdpre.idl"
#include "rstchg.idl"
#include "rstupd.idl"
#include "rstidn.idl"
#include "rstind.idl"
#include "rstcridx.idl"
#include "mulres.idl"
#include "transact.idl"
#include "trnjoi.idl"
#include "trnlcl.idl"
#include "trnobj.idl"
#include "cmdwpr.idl"

cpp_quote("#include <accctrl.h>")

cpp_quote("#pragma pack(pop)")
cpp_quote("")
