/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifdef __WIDL__
#pragma winrt
#endif

import "dxgi.idl";
import "inspectable.idl";
import "windows.graphics.directx.direct3d11.idl";

namespace Windows.Graphics.DirectX.Direct3D11 {
    HRESULT CreateDirect3D11DeviceFromDXGIDevice([in] IDXGIDevice* dxgiDevice, [out] IInspectable** graphicsDevice);

    [
        uuid(A9B3D012-3DF2-4EE3-B8D1-8695F457D3C1)
    ]
    interface IDirect3DDxgiInterfaceAccess : IUnknown {
        HRESULT GetInterface([in] REFIID iid, [out, iid_is(iid)] void **object);
    };
}
