/*
 * Copyright (C) 1999 Francois Gouget
 * Copyright (C) 2003 Alexandre Julliard
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

import "objidl.idl";


/*****************************************************************************
 * IServiceProvider interface
 */
[
    object,
    uuid(6d5140c1-7436-11ce-8034-00aa006009fa),
    pointer_default(unique)
]
interface IServiceProvider : IUnknown
{
    typedef [unique] IServiceProvider *LPSERVICEPROVIDER;

    [local]
    HRESULT QueryService(
        [in] REFGUID guidService,
        [in] REFIID riid,
        [out] void ** ppvObject);

    [call_as(QueryService)]
    HRESULT RemoteQueryService(
        [in] REFGUID guidService,
        [in] REFIID riid,
        [out, iid_is(riid)] IUnknown ** ppvObject);
}
